Validates that the portfolio data has the columns required for a simple portfolio:
company_id, company_name, exposure_value_usd, term,
loss_given_default. No country_iso2 is required.
Validates that the portfolio data has the columns required for a simple portfolio:
company_id, company_name, exposure_value_usd, term,
loss_given_default. No country_iso2 is required.